==> 1.0.3.tar.gz: lib/games_services_platform_interface/game_services_platform_interface.dart <==
import 'dart:async';

import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:vgk_game_services/games_services_platform_interface/method_channel_games_services.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/access_point_location.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/achievement.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/score.dart';

abstract class GamesServicesPlatform extends PlatformInterface {
  GamesServicesPlatform() : super(token: _token);

  static final Object _token = Object();

  static GamesServicesPlatform _instance = MethodChannelGamesServices();

  static GamesServicesPlatform get instance => _instance;

  static set instance(GamesServicesPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> increment({achievement: Achievement}) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> unlock({achievement: Achievement}) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> submitScore({score: Score}) async {
    throw UnimplementedError("not implemented.");
  }

  /// It will open the achievements screen.
  Future<String?> showAchievements() async {
    throw UnimplementedError("not implemented.");
  }

  /// It will open the leaderboards screen.
  Future<String?> showLeaderboards(
      {iOSLeaderboardID = "", androidLeaderboardID = ""}) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> signIn() async {
    throw UnimplementedError("not implemented.");
  }

  Future<bool?> get isSignedIn => throw UnimplementedError("not implemented.");

  Future<String?> signOut() async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> showAccessPoint(AccessPointLocation location) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> hideAccessPoint() async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> getPlayerID() async {
    throw UnimplementedError("not implemented.");
  }
}

==> 1.2.1.tar.gz: lib/games_services_platform_interface/game_services_platform_interface.dart <==
import 'dart:async';

import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:vgk_game_services/games_services_platform_interface/method_channel_games_services.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/access_point_location.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/achievement.dart';
import 'package:vgk_game_services/games_services_platform_interface/models/score.dart';

abstract class GamesServicesPlatform extends PlatformInterface {
  GamesServicesPlatform() : super(token: _token);

  static final Object _token = Object();

  static GamesServicesPlatform _instance = MethodChannelGamesServices();

  static GamesServicesPlatform get instance => _instance;

  static set instance(GamesServicesPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> increment({achievement = Achievement}) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> unlock({achievement = Achievement}) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> submitScore({score = Score}) async {
    throw UnimplementedError("not implemented.");
  }

  /// It will open the achievements screen.
  Future<String?> showAchievements() async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> showLeaderboards(
      {iOSLeaderboardID = "", androidLeaderboardID = ""}) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> signIn() async {
    throw UnimplementedError("not implemented.");
  }

  Future<bool?> get isSignedIn => throw UnimplementedError("not implemented.");

  Future<String?> signOut() async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> showAccessPoint(AccessPointLocation location) async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> hideAccessPoint() async {
    throw UnimplementedError("not implemented.");
  }

  Future<String?> getPlayer() async {
    throw UnimplementedError("not implemented.");
  }
}
